@@ -248,6 +248,8 @@ TEMP_CACHE_DIR_PREFIX = "hf_datasets-"
 # Streaming
 STREAMING_READ_MAX_RETRIES = 20
 STREAMING_READ_RETRY_INTERVAL = 5
+STREAMING_READ_SERVER_UNAVAILABLE_RETRY_INTERVAL = 20
+STREAMING_READ_RATE_LIMIT_RETRY_INTERVAL = 60
 STREAMING_OPEN_MAX_RETRIES = 20
 STREAMING_OPEN_RETRY_INTERVAL = 5
 
